@@ -21,20 +21,20 @@ else
     major_minor="${version_to_build%.*}"
   elif [[ "${package_to_build}" == "gcc" ]]; then
     if [[ -z "${arg_b:-${arg_B}}" ]]; then
-      gcc_url_head="ftp://ftp.gnu.org:/gnu/gcc/gcc-${version_to_build}/"
+      gcc_url_head="https://ftpmirror.gnu.org/gcc/gcc-${version_to_build}/"
     else
       gcc_url_head="svn://gcc.gnu.org/svn/gcc/"
     fi
   fi
   package_url_head=(
     "gcc;${gcc_url_head-}"
-    "wget;ftp://ftp.gnu.org:/gnu/wget/"
-    "m4;ftp://ftp.gnu.org:/gnu/m4/"
+    "wget;https://ftpmirror.gnu.org/gnu/wget/"
+    "m4;https://ftpmirror.gnu.org/gnu/m4/"
     "pkg-config;https://pkgconfig.freedesktop.org/releases/"
     "mpich;https://www.mpich.org/static/downloads/${version_to_build-}/"
     "flex;https://sourceforge.net/projects/flex/files/"
-    "make;ftp://ftp.gnu.org/gnu/make/"
-    "bison;ftp://ftp.gnu.org:/gnu/bison/"
+    "make;https://ftpmirror.gnu.org/gnu/make/"
+    "bison;https://ftpmirror.gnu.org/gnu/bison/"
     "cmake;https://www.cmake.org/files/v${major_minor:-}/"
     "subversion;https://www.eu.apache.org/dist/subversion/"
   )
@@ -53,10 +53,10 @@ else
   # Set differing tails for GCC release downloads versus development branch checkouts
   if [[ "${package_to_build}" == 'gcc' ]]; then
     if [[ "${fetch}" == 'svn' ]]; then
-      if [[ "${version_to_build}" == "trunk" ]]; then
+      if [[ "${version_to_build:-}" == "trunk" ]]; then
         gcc_tail="${version_to_build}"
       else
-        gcc_tail="branches/${version_to_build}"
+        gcc_tail="branches/${version_to_build:-}"
       fi
     else
       gcc_tail="gcc-${version_to_build}.tar.gz"
@@ -71,9 +71,13 @@ else
     "flex;flex-${version_to_build-}.tar.bz2"
     "bison;bison-${version_to_build-}.tar.gz"
     "make;make-${version_to_build-}.tar.bz2"
-    "cmake;cmake-${version_to_build-}.tar.gz"
     "subversion;subversion-${version_to_build-}.tar.gz"
   )
+  if [[ $(uname) == "Linux" ]]; then
+    package_url_tail+=("cmake;cmake-${version_to_build}-Linux-x86_64.sh")
+  else
+    package_url_tail+=("cmake;cmake-${version_to_build-}.tar.gz")
+  fi
   for package in "${package_url_tail[@]}" ; do
      KEY="${package%%;*}"
      VALUE="${package##*;}"
@@ -84,6 +88,7 @@ else
      fi
   done
 
+
   if [[ -z "${url_head:-}" || -z "${url_tail}" ]]; then
     emergency "Package ${package_name:-} not recognized.  Use --l or --list-packages to list the allowable names."
   fi
