@@ -97,15 +97,16 @@ info "-e (--verbose):          ${arg_e} "
 info "-f (--with-fortran):     ${arg_f} "
 info "-h (--help):             ${arg_h} "
 info "-i (--install-prefix):   ${arg_i} "
-info "-j (--num-threads):      ${arg_j} "
 info "-I (--install-version):  ${arg_I} "
+info "-j (--num-threads):      ${arg_j} "
 info "-l (--list-packages):    ${arg_l} "
 info "-m (--with-cmake):       ${arg_m} "
 info "-M (--with-mpi):         ${arg_M} "
 info "-n (--no-color):         ${arg_n} "
+info "-o (--only-download):    ${arg_o} "
 info "-p (--package):          ${arg_p} "
 info "-P (--print-path):       ${arg_P} "
-info "-t (--with-tau):         ${arg_t} "
+info "-r (--prefix-root):      ${arg_r} "
 info "-u (--from-url):         ${arg_u} "
 info "-U (--print-url):        ${arg_U} "
 info "-v (--version):          ${arg_v} "
