@@ -1,6 +1,6 @@
 ! BSD 3-Clause License
 !
-! Copyright (c) 2018, Sourcery Institute
+! Copyright (c) 2018-2019, Sourcery Institute
 ! All rights reserved.
 !
 ! Redistribution and use in source and binary forms, with or without
@@ -31,12 +31,15 @@ program main
   !! summary: Test team_number intrinsic function
   use iso_fortran_env, only : team_type
   use iso_c_binding, only : c_loc
+  use oc_assertions_interface, only : assert
 
   implicit none
 
   integer, parameter :: standard_initial_value=-1
 
-  type(team_type), target :: home
+  type(team_type) :: parent, child
+
+  if (num_images() < 8) error stop "I need at least 8 images to function."
 
   call assert(team_number()==standard_initial_value,"initial team number conforms with Fortran standard before 'change team'")
 
@@ -46,11 +49,17 @@ program main
    !! TODO: uncomment the above assertion after implementing support for team_number's optional argument:
 
   after_change_team: block
-    associate(my_team=>mod(this_image(),2)+1)
+    associate(parent_team_number => 100 + (num_images()-1)/4, child_team_number => 1000 + mod(num_images()-1,4)/2)
       !! Prepare for forming two teams: my_team = 1 for even image numbers in the initial team; 2 for odd image numbers
-      form team(my_team,home)
-      change team(home)
-        call assert(team_number()==my_team,"team number conforms with Fortran standard after 'change team'")
+      form team(parent_team_number,parent)
+      change team(parent)
+        call assert(team_number()==parent_team_number,"team number conforms with Fortran standard after 'change team'")
+        form team (child_team_number, child)
+        change team(child)
+          call assert(team_number()==child_team_number,"team number conforms with Fortran standard after 'change team'")
+          call assert(team_number(child)==child_team_number,"team_number(child) conforms with Fortran standard after 'change team'")
+          call assert(team_number(parent)==parent_team_number,"team_number(parent) conforms with Fortran standard")
+        end team
       end team
       call assert(team_number()==standard_initial_value,"initial team number conforms with Fortran standard")
     end associate
@@ -59,18 +68,4 @@ program main
   sync all
   if (this_image()==1) print *,"Test passed."
 
-contains
-
-  elemental subroutine assert(assertion,description)
-    !! TODO: move this to a common place for all tests to use
-    logical, intent(in) :: assertion
-    character(len=*), intent(in) :: description
-    integer, parameter :: max_digits=12
-    character(len=max_digits) :: image_number
-    if (.not.assertion) then
-      write(image_number,*) this_image()
-      error stop "Assertion " // description // "failed on image " // trim(image_number)
-    end if
-  end subroutine
-
 end program
